package	jp.co.sds_corp.transfer.layout;

import java.util.Iterator;
import java.util.List;

import jp.co.sds_corp.transfer.IData;

/**
* 指定されたフォーマット文字列を元に、データを編集します。
*/
public abstract class PatternLayout implements ILayout
{
	String	fmt;
	List<IConverter>	list;

	/**
	* フォーマット文字列を指定します。
	* @param	fmt		フォーマット文字列
	*/
	public void setFormat( String fmt ) {
		this.fmt = fmt;
		list = createParser( fmt ).parse();
	}

	/**
	* {@link FormatParser}を生成します。
	* @param	fmt		フォーマット文字列
	*/
	public abstract FormatParser createParser( String fmt );

	/**
	* 文字列を編集して出力します。
	* @param	data	編集元のデータ
	* @return	編集結果の文字列
	*/
	public String format( IData data ) {
		StringBuffer buf = new StringBuffer();
		Iterator<IConverter> itr = list.iterator();
		while ( itr.hasNext()) {
			IConverter cvt = (IConverter )itr.next();
			buf.append( cvt.convert( data ));
		}
		return buf.toString();
	}

	/**
	* このレイアウトの文字列表現を返します。
	* @return	このレイアウトの文字列表現を返します。
	*/
	public String toString() {
		String ret = getClass().getName() + " format=[" + fmt + "]";
		return ret;
	}
}
