package	jp.co.sds_corp.transfer.output;

import java.util.List;
import java.util.Vector;

import jp.co.sds_corp.transfer.ReceiveEvent;
import jp.co.sds_corp.transfer.StatusChangeEvent;
import jp.co.sds_corp.transfer.filter.IFilter;
import jp.co.sds_corp.util.config.IConfiguration;
import jp.co.sds_corp.util.daemon.AbstractService;
import jp.co.sds_corp.util.log.CmnLogFactory;
import jp.co.sds_corp.util.log.CmnLogger;

/**
* データ出力クラスの基底クラスです。
*/
public abstract class AbstractOutput extends AbstractService
	implements IOutput
{
	static final CmnLogger logger = CmnLogFactory.getLogger();
	Vector<IFilter>		vecFilter = new Vector<IFilter>();
	boolean		debug = false;

	/**
	* 指定された初期情報で初期化します。
	* @param	config	初期情報
	*/
	public void init( IConfiguration config ) throws Exception {
		String var;
		var = config.get( "debug", "false" );
		debug = var.equals( "true" );
	}

	/**
	* このサービスを開始します。
	*/
	public void start() {
	}

	/**
	* このサービスを停止します。
	*/
	public void stop() {
	}

	/**
	* 状態に何らかの変更があったときに呼び出されます。
	* @param	e		イベントソースおよび状態の変更内容を指定します。
	*/
	public void statusChanged( StatusChangeEvent e ) throws Exception {
		if ( isDebug() ) {
			logger.debug( this, e.toString() );
		}
	}

	/**
	* データのフィルタを設定します。
	* @param	var		設定するフィルタ
	*/
	public void addFilter( IFilter var ) {
		vecFilter.add( var );
	}

	/**
	* データのフィルタを削除します。
	* @param	var		削除するフィルタ
	*/
	public void removeFilter( IFilter var ) {
		vecFilter.remove( var );
	}

	/**
	* データのフィルタを取得します。
	* @return	設定されているフィルタの格納されている{@link List}
	*/
	public List<IFilter> getFilterList() {
		return vecFilter;
	}

	/**
	* データのフィルタリングを行なう
	* @param	e		データ受信イベント
	*/
	public boolean isValid( ReceiveEvent e ) throws Exception {
		List<IFilter> list;
		list = getFilterList();
		for ( int i = 0; i < list.size(); i++ ) {
			IFilter flt = (IFilter )list.get( i );
			if ( flt.isTarget( e )) {
				if ( !flt.isValid( e )) {
					flt.putLog( "[OUT]", e );
					return false;
				}
			}
		}
		return true;
	}

	/**
	* デバッグフラグ(debug)を設定します。
	* @param	var		設定するデータ
	*/
	public void setDebug( boolean var ) {
		this.debug = var ;
	}
	/**
	* デバッグフラグ(debug)を取得します。
	* @return	debugの内容
	*/
	public boolean isDebug() {
		return debug;
	}

}
